---
title: "A Brief History of Obscenity Law"
author: "Carlos Ball"
image: img/carlos-ball.jpg
era: "Contemporary"
topic: "Free Speech"
draft: false
---

*The following is an excerpt from chapter one of “[The First Amendment and LGBT Equality](https://www.amazon.com/First-Amendment-LGBT-Equality-Contentious-ebook/dp/B06XVBY2SL/ref=tmm_kin_swatch_0?_encoding=UTF8&qid=&sr=)“, by Carlos A. Ball.*

**A Brief History of Obscenity**

During approximately the first 120 years of obscenity prosecutions in the United States (that is, roughly between the 1810s until the 1930s), courts frequently, and without much controversy or disagreement, pointed to the promotion of public morality as the main objective behind obscenity laws…

…The first reported obscenity conviction in the United States took place in Philadelphia in 1815. The defendants in Commonwealth v. Sharpless were charged under the common-law crime of public indecency for allowing members of the public, after paying a fee, to enter “a certain house” in order to observe a painting “representing a man in an obscene, impudent and indecent posture with a woman.” In upholding the convictions, the Pennsylvania Supreme Court explained that “what tended to corrupt society, was … a breach of the peace and punishable by indictment. The courts are guardians of the public morals.… Hence, it follows, that an offence may be punishable, if in its nature and by its example, it tends to the corruption of morals.”…

…Congress enacted the [Comstock Act](https://www.britannica.com/event/Comstock-Act) obscenity statute in 1873, making it a federal crime to use the mails to distribute “obscene, lewd, or lascivious” publications. In addition to criminalizing the distribution of obscene materials via the mails, the act authorized the Post Office to refuse to mail obscene materials….

…The same focus on morality continued well into the twentieth century. For example, in 1928, the publisher [Donald Friede was charged under New York’s obscenity statute](https://www.casemine.com/judgement/us/5914777badd7b049343d4c05) for publishing the lesbian novel The Well of Loneliness. That novel, which had been deemed obscene in England, tells the story of a woman who initially struggles with her sexual attraction to women only to later understand and accept her sexual orientation.

In rejecting the defendant’s motion to have the criminal charge dismissed, the magistrate judge reasoned that “the novel is not only anti-social and offensive to public morals and decency,” but also written in a way that “attract[ed] and focus[ed] attention upon perverted ideas and unnatural vices and [was] strongly calculated to corrupt and debase those members of the community who would be susceptible to its immoral influence.” The magistrate was particularly concerned with the novel’s moral impact on those who might find same-sex sexual conduct appealing. In response to the publisher’s argument that the [Hicklin test](https://en.wikipedia.org/wiki/Hicklin_test) inappropriately relied on the susceptibilities of society’s “dullest-witted and most fallible members” to determine what was obscene, the judge noted that this particular novel, which was literary and well-written, was problematic precisely because it aimed to corrupt “those of mature age and of high intellectual development and professional attainment.”

In upholding the obscenity prosecution, the magistrate embraced the notion of “thematic obscenity,” that is, the idea that a publication was obscene if it presented intimate relationships outside of heterosexual marriage as morally acceptable, even in the absence of explicit depictions of sexual acts. The judge expressed particular concern about the novel’s portrayal of “unnatural and depraved” (that is, same-sex) relationships as ones that were to be “idealized and extolled.” Rather than criticizing these relationships, the book presented the characters “who indulge in these vices … in attractive terms, and it is maintained throughout that they be accepted on the same plane as persons normally constituted, and that their perverse and inverted love is as worthy as the affection between normal beings and should be considered just as sacred by society.”…

…The promotion of public morality through law was grounded in the notion that it was appropriate for the state to discourage individuals from engaging in conduct that society deemed to be morally wrong. …Although courts in the nineteenth and early twentieth centuries embraced public morality as the normative basis for obscenity law, around the 1930s a growing number of judges began to express skepticism of the notion that public morality granted the government virtually untrammeled discretion to regulate obscenity…

The national mobilization engendered by World War II helped to create the conditions that allowed for the emergence of the homophile movement, as the early LGBT rights movement called itself. The war brought together millions of men and women in single-sex environments, leading some to realize that they were not alone in experiencing same-sex attraction. After the war, many of these individuals chose not to return to their places of origin, and instead relocated to large urban areas where others with similar sexual and romantic interests lived…

Although …repression caused much suffering, it also encouraged a band of brave LGBT activists to come together to do what they could to protect their communities and themselves from government coercion and harassment. The first homophile organization, the Mattachine Society, was formed in Los Angeles in 1951 by a handful of men, most of whom were former members of the Communist Party.

The early years of the [Mattachine Society](https://en.wikipedia.org/wiki/Mattachine_Society) were characterized by considerable infighting and a penchant for secrecy. This led a group of dissatisfied members, both men and women, to create a new organization with the goal of publishing a magazine that would advocate for gay equality more openly. The purpose of the magazine, as expressed in the articles of incorporation of the nonprofit entity that published it, was to address “homosexuality from the scientific, historical and critical point of view, and to aid in the social integration and rehabilitation of the sexual variant.” The founders called their magazine ONE (letters capitalized) based on the nineteenth-century Scottish writer Thomas Carlyle’s declaration that “a mystic bond of brotherhood makes all men one.”

The first issue of ONE, published in January 1953, included an account by Dale Jennings, a cofounder of both the Mattachine Society and ONE, of his arrest and trial in Los Angeles for allegedly soliciting a male undercover vice-squad police officer to commit a sexual act. Early issues also included poetry, fiction, and news clippings on topics of interest to gay people. In addition, several of ONE’s articles decried the treatment of lesbians and gay men by police authorities and called for an end to the entrapment tactics of vice squads.

At first, newsstand operators refused to carry the magazine, but after sales in gay bars in Los Angeles proved there was a market for the publication, some newsstands agreed to sell it. As for those who subscribed, most paid extra to have the magazine sent to them first class, in sealed envelopes without a return address.

By July 1953, the magazine’s paid circulation had reached two thousand, with a readership that was considerably larger given that copies were frequently circulated among friends. Letters to the editor indicated that the magazine was being read across the country. The fear of being identified as gay or lesbian meant that the letters were often published without accompanying names, sometimes with the only identifying information being “m” for male and “f” for female, in addition to the name of the town and state where the writer lived…

…Although staff members did not know it at the time, three months after the magazine was first published, FBI agents in Los Angeles began reading it in search of obscene or subversive material. In July 1953, the FBI opened a formal investigation of the magazine, which included mailing each issue to FBI headquarters in Washington for further review. A few weeks later, local postal authorities seized copies of ONE’s August issue pending review by officials in Washington to determine whether it was mailable under the federal obscenity statute. That particular issue, with a cover titled “Homosexual Marriage?,” included the first article published in a gay American magazine discussing whether the law should allow same-sex couples to marry. Only after officials in Washington determined that the issue was mailable did the Post Office distribute the copies, three weeks after it had seized them….

…In response to complaints from some readers that the magazine was too tame, the editors also asked Julber to write an essay, published in the October 1954 issue—the same issue that postal officials later seized after deeming it obscene—detailing how the magazine determined what it could publish in order to steer clear of obscenity laws. Julber opined that ONE did not run afoul of obscenity statutes as long as it published materials limited to “the discussion of the social, economic, personal and legal problems of homosexuals, for the purpose of better understanding of and by society.” But the magazine had to stay away from materials that “appealed to the lusts or salacity or sexual appetites … of ONE’s readers.… ONE, in other words can appeal to the heads, but not the sexual desires, of its readers.” Julber then proceeded to list the kinds of contributions that could not be published, including “lonely hearts ads, … ‘cheesecake’ art or photos, … descriptions of experiences [that are] too explicit, … descriptions of homosexuality as a practice which the author encourages in others, or waxes too enthusiastic about [and] fiction with too much physical contact between the characters.” Ironically, postal authorities refused to mail the approximately six hundred copies of the issue—sardonically titled “You can’t print it!”—containing Julber’s explanations of ONE’s obscenity prevention policies…

…Several months after the Post Office seized their issue, ONE’s editors authorized Julber to file a lawsuit in federal court challenging the government’s action. (Julber asked the American Civil Liberties Union for assistance, but the organization turned down the request because the magazine was a gay one.) After the trial court ruled in the government’s favor, Julber appealed. But a federal appellate court rejected his claim that the government had violated the Free Speech Clause in refusing to mail the gay magazine. In doing so, it explained that whether material was obscene under the federal obscenity statute could only be determined “by some discussion of the moral sense of the public.” Recognizing that “morals are not static,” the judges believed it was necessary to define the statutory terms “in the light of today’s moral dictionary.”…

…ONE responded to the Court of Appeals’ decision with an angry and pugnacious editorial explaining that the magazine saw itself as fighting for the free speech rights of all Americans and that, in some ways, the Post Office had done it a favor by raising the issue of its rights under the First Amendment: “Events may prove that in no other way could the rights of homosexual American citizens be adequately and finally tested, and the legal and social problems of the homosexual be thoroughly and publicly aired.” The editorial also complained that lesbians and gay men were permitted few outlets of expression and that whenever someone wrote realistically about “homosexual attachment—the specter of Obscenity stands ready with fangs bared.” The editorial ended with a promise: “ONE intends to fight to … insure for homosexuals the right to speak for themselves, to publish and disseminate literature wherein the homosexual may answer the prejudice and false charges against him with facts and forthright statements. In simple words, ONE rightfully demands the ‘Freedom of the Press.’”…

…The Supreme Court granted the certiorari petition in [One v. Olesen](https://mtsu.edu/first-amendment/article/406/one-inc-v-olesen-9th-cir), but rather than asking for briefs and scheduling oral arguments, it instead summarily reversed the Court of Appeals in a one-sentence, unanimous, and *per curiam* [unsigned] opinion that cited to Roth v United States. It was not surprising that the Supreme Court, in reversing the lower court’s ruling, cited Roth, its most important obscenity decision to date, issued several months after the federal appellate decision in One and several weeks before ONE filed its certiorari petition. Clearly, the Supreme Court did not believe that the October 1954 issue of the gay magazine was obscene under Roth. The question that remains unanswered—and will likely never be definitively answered given its summary reversal in One—is precisely why the Court so believed.

Despite the unavoidable uncertainty that accompanies one-sentence rulings, it is possible, in looking at One and Roth together, to reach reasonable conclusions about the Court’s prevailing views on obscenity as they applied to a gay publication. First, the Court likely concluded, after presumably analyzing the magazine’s content, that it did not sufficiently appeal to prurient interests to qualify as obscene under Roth. The Court, it is reasonable to believe, concluded that the magazine lacked the minimum degree of explicit sexual content required to support a finding that its primary objective was to appeal to the prurient interests of its readers.

At the same time, however, the magazine did have some sexual content. The issue in question, after all, included a story about a romantic relationship between two women; a sardonic poem about the same-sex interests of some British peers and the visit to public bathrooms by men looking for sex with other men; and an advertisement by a Swiss magazine that, in addition to publishing political and sociological articles, contained erotic pictures.81 But, as we have seen, the Court had made clear in Roth that “sex and obscenity are not synonymous.” What distinguished permissible from impermissible depictions and references to sex under Roth was the extent of the material’s social value. The second reasonable conclusion that we can reach when interposing the two cases, therefore, is that the gay magazine’s content, to use Judge Horn’s phrase, manifested, at the very least, “the slightest redeeming social importance.”

It is in many ways astounding that the Supreme Court in 1958 was willing to recognize that a magazine dedicated to the needs and interests of lesbians and gay men had sufficient social importance—despite containing some sexual content—to reverse the lower court’s finding of obscenity. In thinking about what the Court did in One, it is essential to keep in mind the prevailing social consensus that same-sex sexual relationships and conduct were immoral and deviant. As the two leading commentators on obscenity law noted at the time, “it could scarcely be said that One, The Homosexual Magazine enjoys any substantial degree of public acceptance in the nation or that it comports with contemporary standards of the average or majority of the national community.”

The outcome in One strongly suggests the Court believed that, for purposes of determining the scope of free speech protections, the assessment of the social value of publications deemed by the government to be obscene had to be conducted independently of majoritarian judgments about the morality of the sexual relationships and conduct depicted therein. Indeed, One reflects the extent to which the Supreme Court by the late 1950s had embraced the idea that majoritarian moral objections to certain kinds of sexual relationships and acts should be kept separate from the determination of whether particular materials were legally obscene. If the Court in One had accepted the federal appellate court’s reasoning that the morality of the sexual relationships in question, as determined by contemporary social standards, was a crucial factor in assessing whether the materials were legally obscene, it is highly unlikely that it would have protected the gay magazine under the First Amendment.

One constituted another instance in which the government invited the Court to link the state’s authority to regulate obscenity to the preservation of public morals. Its unwillingness to do so foreshadowed its holding the following year in Kingsley Pictures that the government could not constitutionally prevent the distribution of materials on the ground that they promoted immoral relationships.

After One, it became clear that the government could not censor a publication dedicated to exploring the place of sexual minorities in society, even if most Americans deemed same-sex sexual relationships and conduct to be morally unacceptable. What was not so clear was whether the First Amendment provided protection to publications that, for their era, had significant same-sex erotic content…

…[Nevertheless,] ONE’s legal victory allowed for the continuation and expansion of a phenomenon that had never before taken place in American history: lesbians and gay men sharing their views in print about both their sexuality and their place in society. This expression took place not only through the publication of homophile magazines such as ONE, the Mattachine Review (published by the Mattachine Society), and the Ladder (published by the Daughters of Bilitis), but also through other printed forms, such as the growing number of novels being published with gay and lesbian themes. During the late 1950s and early 1960s, for example, there was an explosion in the publication of lesbian pulp novels, many of which contained positive, and increasingly erotic, portrayals of female same-sex sexual relationships. If the Court in One had affirmed the government’s victory in the lower courts, it would have made it possible for prosecutors and other law enforcement officials to prevent the distribution of books and magazines simply on the basis that they contained lesbian and gay themes. The fact that the government after One could no longer justify its regulation of publications aimed at presenting same-sex sexual relationships and conduct in a positive light on the ground that they violated society’s moral strictures provided constitutional protection for publishers, writers, and advocates who questioned those strictures. The judicial victory encouraged the publication of books and magazines that helped to render lesbians and gay men more visible, and to do so on terms set by them rather than by a hostile society.